==> igniteui-react-charts-16.6.8.tgz: package/ES2015/AnchoredCategorySeriesInteractionManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core/ES2015/type";
import { IAnchoredCategorySeriesInteractionManager_$type } from "./IAnchoredCategorySeriesInteractionManager";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { ScalerParams } from "./ScalerParams";
import { truncate, intDivide, isNaN_ } from "igniteui-react-core/ES2015/number";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES2015/string";
/**
 * @hidden
 */
export class AnchoredCategorySeriesInteractionManager extends Base {
    c$b(a, b, c, d, e, f, g, h) {
        if (!g) {
            return h(b);
        }
        if (e == null || e.cc || f == null || d == null || isNaN_(b.x) || isNaN_(b.y)) {
            return h(b);
        }
        if (c <= 1) {
            return h(b);
        }
        let i = truncate(Math.round(a.d8(b)));
        if (i < 0 || i >= a.bz.count) {
            return h(b);
        }
        let j = intDivide(i, c);
        let k = c * j;
        let l = Math.min(k + c, d.count - 1);
        let m = a.lj(a.bi);
        let n = new ScalerParams(0, a.bs.m4, a.bs.m3, f.b8, a.bs.mu);
        let o = m.top;
        let p = m.bottom;
        let q = o + (p - o) * b.y;
        let r = f.dw(q, n);
        let s = 1.7976931348623157E+308;
        let t = k;
        for (let u = k; u <= l; u++) {
            let v = Math.abs(d.item(u) - r);
            if (v < s) {
                s = v;
                t = u;
            }
        }
        return a.bz.item(t);
    }
    c$a(a, b, c, d, e, f) {
        let g = a.bi.bs;
        g = g.copy();
        let h = a.bi.br;
        let i = new Rect(0, 0, 0, 1, 1);
        let j = !g.isEmpty && !h.isEmpty && a.bz != null ? a.bz.indexOf(f) : -1;
        let k = a.ll(a.bi);
        let l = new ScalerParams(0, i, i, c.b8, k);
        let m = new ScalerParams(0, i, i, d.b8, k);
        m.b = a.ee();
        let n = c != null ? c.dt(j, l) : NaN;
        n += e;
        let o = d != null && b != null && j < b.count ? d.dt(b.item(j), m) : NaN;
        if (!isNaN_(n)) {
            if (n < g.left + 0.1 * g.width) {
                n = n + 0.4 * g.width;
                g.x = n - 0.5 * g.width;
            }
            if (n > g.right - 0.1 * g.width) {
                n = n - 0.4 * g.width;
                g.x = n - 0.5 * g.width;
            }
        }
        if (!isNaN_(o)) {
            if (o < g.top + 0.1 * g.height) {
                o = o + 0.4 * g.height;
                g.y = o - 0.5 * g.height;
            }
            if (o > g.bottom - 0.1 * g.height) {
                o = o - 0.4 * g.height;
                g.y = o - 0.5 * g.height;
            }
        }
        if (a.bn != null) {
            a.bn.ap(a.bs, g, true);
        }
        return j >= 0;
    }
    c$c(a, b) {
        let c = "<div class='ui-chart-default-tooltip-content'>";
        let d = null;
        d = a.ap();
        if (d.b5) {
            let e = d;
            c += "<span>${item." + e.dateTimeMemberPath + "}</span><br/>";
        }
        else if (d != null && d.e2 != null) {
            c += "<span>${item." + d.e2 + "}</span><br/>";
        }
        c += "<span";
        let f = a.a0.a$q(a);
        if (!stringIsNullOrEmpty(f)) {
            c += " style='color:" + f + "'";
        }
        c += ">${series.title}: </span><span class='ui-priority-primary'>" + "${item." + b + "}</span></div>";
        return c;
    }
    c$d(a, b, c, d, e, f, g, h) {
        if (c == null || d == null) {
            return Rect.empty;
        }
        let i = a.k9(b);
        let j = a.bi.bs;
        let k = a.bi.br;
        let l = a.getEffectiveViewport1(a.bi);
        let m = new ScalerParams(0, j, k, d.b8, l);
        m.b = a.ee();
        let n = a.aj(a.ap(), e.f, f, g, b, true);
        if (n == null) {
            return Rect.empty;
        }
        let o = n[0];
        let p = n[1];
        let q = Math.abs(i.x - o[0]);
        let r = Math.abs(i.x - p[0]);
        let s = d.dt(d.j7, m);
        let t = c.jk(j, k, l);
        if (q < r) {
            let u = o[0] - 0.5 * t;
            let v = h(o);
            let w = s;
            return new Rect(0, u, Math.min(v, w), t, Math.max(v, w) - Math.min(v, w));
        }
        else {
            let x = p[0] - 0.5 * t;
            let y = h(p);
            let z = s;
            return new Rect(0, x, Math.min(y, z), t, Math.max(y, z) - Math.min(y, z));
        }
    }
}
AnchoredCategorySeriesInteractionManager.$t = markType(AnchoredCategorySeriesInteractionManager, 'AnchoredCategorySeriesInteractionManager', Base.$, [IAnchoredCategorySeriesInteractionManager_$type]);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/AnchoredCategorySeriesInteractionManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core/ES2015/type";
import { IAnchoredCategorySeriesInteractionManager_$type } from "./IAnchoredCategorySeriesInteractionManager";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { ScalerParams } from "./ScalerParams";
import { truncate, intDivide, isNaN_ } from "igniteui-react-core/ES2015/number";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES2015/string";
/**
 * @hidden
 */
export class AnchoredCategorySeriesInteractionManager extends Base {
    c$b(a, b, c, d, e, f, g, h) {
        if (!g) {
            return h(b);
        }
        if (e == null || e.cd || f == null || d == null || isNaN_(b.x) || isNaN_(b.y)) {
            return h(b);
        }
        if (c <= 1) {
            return h(b);
        }
        let i = truncate(Math.round(a.eb(b)));
        if (i < 0 || i >= a.bz.count) {
            return h(b);
        }
        let j = intDivide(i, c);
        let k = c * j;
        let l = Math.min(k + c, d.count - 1);
        let m = a.lq(a.bi);
        let n = new ScalerParams(0, a.bs.m4, a.bs.m3, f.b8, a.bs.mu);
        let o = m.top;
        let p = m.bottom;
        let q = o + (p - o) * b.y;
        let r = f.dz(q, n);
        let s = 1.7976931348623157E+308;
        let t = k;
        for (let u = k; u <= l; u++) {
            let v = Math.abs(d.item(u) - r);
            if (v < s) {
                s = v;
                t = u;
            }
        }
        return a.bz.item(t);
    }
    c$a(a, b, c, d, e, f) {
        let g = a.bi.bs;
        g = g.copy();
        let h = a.bi.br;
        let i = new Rect(0, 0, 0, 1, 1);
        let j = !g.isEmpty && !h.isEmpty && a.bz != null ? a.bz.indexOf(f) : -1;
        let k = a.ls(a.bi);
        let l = new ScalerParams(0, i, i, c.b8, k);
        let m = new ScalerParams(0, i, i, d.b8, k);
        m.b = a.eh();
        let n = c != null ? c.dw(j, l) : NaN;
        n += e;
        let o = d != null && b != null && j < b.count ? d.dw(b.item(j), m) : NaN;
        if (!isNaN_(n)) {
            if (n < g.left + 0.1 * g.width) {
                n = n + 0.4 * g.width;
                g.x = n - 0.5 * g.width;
            }
            if (n > g.right - 0.1 * g.width) {
                n = n - 0.4 * g.width;
                g.x = n - 0.5 * g.width;
            }
        }
        if (!isNaN_(o)) {
            if (o < g.top + 0.1 * g.height) {
                o = o + 0.4 * g.height;
                g.y = o - 0.5 * g.height;
            }
            if (o > g.bottom - 0.1 * g.height) {
                o = o - 0.4 * g.height;
                g.y = o - 0.5 * g.height;
            }
        }
        if (a.bn != null) {
            a.bn.ap(a.bs, g, true);
        }
        return j >= 0;
    }
    c$c(a, b) {
        let c = "<div class='ui-chart-default-tooltip-content'>";
        let d = null;
        d = a.ap();
        if (d.b5) {
            let e = d;
            c += "<span>${item." + e.dateTimeMemberPath + "}</span><br/>";
        }
        else if (d != null && d.e7 != null) {
            c += "<span>${item." + d.e7 + "}</span><br/>";
        }
        c += "<span";
        let f = a.a0.a$q(a);
        if (!stringIsNullOrEmpty(f)) {
            c += " style='color:" + f + "'";
        }
        c += ">${series.title}: </span><span class='ui-priority-primary'>" + "${item." + b + "}</span></div>";
        return c;
    }
    c$d(a, b, c, d, e, f, g, h) {
        if (c == null || d == null) {
            return Rect.empty;
        }
        let i = a.lg(b);
        let j = a.bi.bs;
        let k = a.bi.br;
        let l = a.getEffectiveViewport1(a.bi);
        let m = new ScalerParams(0, j, k, d.b8, l);
        m.b = a.eh();
        let n = a.aj(a.ap(), e.f, f, g, b, true);
        if (n == null) {
            return Rect.empty;
        }
        let o = n[0];
        let p = n[1];
        let q = Math.abs(i.x - o[0]);
        let r = Math.abs(i.x - p[0]);
        let s = d.dw(d.ke, m);
        let t = c.jr(j, k, l);
        if (q < r) {
            let u = o[0] - 0.5 * t;
            let v = h(o);
            let w = s;
            return new Rect(0, u, Math.min(v, w), t, Math.max(v, w) - Math.min(v, w));
        }
        else {
            let x = p[0] - 0.5 * t;
            let y = h(p);
            let z = s;
            return new Rect(0, x, Math.min(y, z), t, Math.max(y, z) - Math.min(y, z));
        }
    }
}
AnchoredCategorySeriesInteractionManager.$t = markType(AnchoredCategorySeriesInteractionManager, 'AnchoredCategorySeriesInteractionManager', Base.$, [IAnchoredCategorySeriesInteractionManager_$type]);
